/**
 * Author:Matt Langston
 * Date: 2013.02.07
 *
 * Provides two event listeners that move a view in response to touch events. The
 * algorithm to move the view uses the touchmove event's {x, y} properties and
 * a 2D transformation matrix. The state requried to move the view is cached
 * completely within JavaScript.
 *
 * See https://jira.appcelerator.org/browse/TIMOB-7999
 */
function CacheInJavaScriptTransformMoveEventListeners(view) {
	var initialLocationInView;
	var transform = Ti.UI.create2DMatrix();

	var touchstartEventListener = function(e) {
		var locationInView = {
			x : e.x,
			y : e.y
		};
		initialLocationInView = locationInView;
	};

	var touchmoveEventListener = function(e) {
		var locationInView = {
			x : e.x,
			y : e.y
		};
		var deltaX = locationInView.x - initialLocationInView.x;
		var deltaY = locationInView.y - initialLocationInView.y;

		transform = transform.translate(deltaX, deltaY);
		var piece = e.source;
		piece.transform = transform;
	};

	view.addEventListener('touchstart', touchstartEventListener);
	view.addEventListener('touchmove', touchmoveEventListener);
};

module.exports = CacheInJavaScriptTransformMoveEventListeners;
